@@ -147,7 +147,7 @@ int open_net(const char *pathname, int flags, mode_t mode) {
 				}
 				read_buf_s = read_buf = malloc(50);
 
-				snprintf(outbuf, sizeof(outbuf), "GET %s HTTP/1.0\nHost: %s\n", file, host);
+				snprintf(outbuf, sizeof(outbuf), "GET %s HTTP/1.0\015\012Host: %s\015\012", file, host);
 
 				write(fd, outbuf, strlen(outbuf));
 
@@ -159,14 +159,13 @@ int open_net(const char *pathname, int flags, mode_t mode) {
 					strcat(smallbuf,password);
 					tmpbuf=mime64(smallbuf);
 
-					snprintf(outbuf, sizeof(outbuf), "Authorization: Basic %s\n", tmpbuf);
+					snprintf(outbuf, sizeof(outbuf), "Authorization: Basic %s\015\012", tmpbuf);
 					write(fd, outbuf, strlen(outbuf));
 
 					free(tmpbuf);
 					free(smallbuf);
-					write(fd, "\n", 1);
 				}
-				write(fd, "\n", 1);
+				write(fd, "\015\012", 2);
 				x=read(fd, read_buf, 50);
 				strsep(&read_buf," ");
 				if (strncmp("200 ",read_buf,4) && strncmp("302 ",read_buf,4)) {
@@ -186,7 +185,7 @@ int open_net(const char *pathname, int flags, mode_t mode) {
 						read(fd, read_buf, 1);
 						read(fd, smallbuf, 510);
 						close(fd);
-						return(open_net(strsep(&smallbuf,"\r\n"),flags,mode));
+						return(open_net(strsep(&smallbuf,"\015\012"),flags,mode));
 						free(tmpbuf);
 					}
 					read_buf[3]=read_buf[2];
@@ -222,7 +221,7 @@ int open_net(const char *pathname, int flags, mode_t mode) {
 					}
 					read_buf[x]=0;
 
-					while ((smallbuf=strsep(&read_buf,"\n"))!=NULL) {
+					while ((smallbuf=strsep(&read_buf,"\012"))!=NULL) {
 						switch (elfcrc(0, smallbuf, 4)) {
 							case 231456: /* 550 */
 								if (ftpfd!=-1) close(ftpfd);
@@ -252,7 +251,7 @@ int open_net(const char *pathname, int flags, mode_t mode) {
 								} else {
 									write(fd, "anonymous", 9);
 								}
-								write(fd, "\n", 1);
+								write(fd, "\015\012", 2);
 								break;
 							case 222768: /* 331 */
 								write(fd, "PASS ", 5);
@@ -261,7 +260,7 @@ int open_net(const char *pathname, int flags, mode_t mode) {
 								} else {
 									write(fd, "user@host.com", 13);
 								}
-								write(fd, "\n", 1);
+								write(fd, "\015\012", 2);
 								break;
 							case 218512: /* 227 */
 								strsep(&smallbuf,"(");
@@ -271,14 +270,14 @@ int open_net(const char *pathname, int flags, mode_t mode) {
 									strcat(host,".");
 								}
 								host[strlen(host)-1]=0;
-								port=(atoi(strsep(&smallbuf,","))<<8)+atoi(strsep(&smallbuf,")\n\r "));
-								write(fd, "TYPE I\n", 7);
+								port=(atoi(strsep(&smallbuf,","))<<8)+atoi(strsep(&smallbuf,")\012\015 "));
+								write(fd, "TYPE I\015\012", 8);
 								break;
 							case 217888:
 								if ((flags&O_RDONLY)==O_RDONLY) write(fd,"RETR ",5);
 								if ((flags&O_WRONLY)==O_WRONLY) write(fd,"STOR ",5);
 								write(fd, file, strlen(file));
-								write(fd, "\n", 1);
+								write(fd, "\015\012", 2);
 								if ((ftpfd=createconnection_tcp(host,port))<0) {
 									close(fd);
 //									errno=ENOENT;
@@ -293,7 +292,7 @@ int open_net(const char *pathname, int flags, mode_t mode) {
 								return(ftpfd);
 								break;
 							case 218656: /* 230 */
-								write(fd, "PASV\n", 5);
+								write(fd, "PASV\015\012", 6);
 								break;
 							default:
 								break;
